@@ -8,6 +8,7 @@ Provides a base class for specialized morphological taggers.
 """
 from corpuscula.corpus_utils import _AbstractCorpus
 from copy import deepcopy
+import gc
 import itertools
 import json
 import junky
@@ -342,9 +343,12 @@ class BaseTagger(BaseParser):
                 res.append(name)
         return res[0] if tostr else res
 
-    def predict(self, field, add_fields, corpus, with_orig=False,
-                batch_size=BATCH_SIZE, split=None, clone_ds=False,
-                save_to=None, log_file=LOG_FILE):
+    def _check_cdict(self, sentence, use_cdict_coef):
+        return sentence
+
+    def predict(self, field, add_fields, corpus, use_cdict_coef=False,
+                with_orig=False, batch_size=BATCH_SIZE, split=None,
+                clone_ds=False, save_to=None, log_file=LOG_FILE):
         """Predicts tags in the specified fields for the corpus.
 
         Args:
@@ -356,6 +360,12 @@ class BaseTagger(BaseParser):
         predictions. May be either a name of the file in *CoNLL-U* format or
         list/iterator of sentences in *Parsed CoNLL-U*.
 
+        **use_cdict_coef** (`bool`|`float`): if `False` (default), we use our
+        prediction only. Elsewise, we replace our prediction to the value
+        returned by the `corpuscula.CorpusDict.predict_<field>()` method if
+        its `coef` >= `.99`. Also, you may specify your own threshold as the
+        value of the param.
+
         **with_orig** (`bool`): if `True`, instead of only a sequence with
         predicted labels, returns a sequence of tuples where the first element
         is a sentence with predicted labels and the second element is original
@@ -454,13 +464,14 @@ class BaseTagger(BaseParser):
                             empties=empties, nones=nones
                         )
                     ):
-                        yield sentence, orig_sentence
+                        yield self._check_cdict(sentence, use_cdict_coef), \
+                              orig_sentence
                 else:
                     for sentence in junky.embed_conllu_fields(
                         corpus_, field, values,
                         empties=empties, nones=nones
                     ):
-                        yield sentence
+                        yield self._check_cdict(sentence, use_cdict_coef)
 
         corpus = process(corpus)
         if save_to:
@@ -469,8 +480,8 @@ class BaseTagger(BaseParser):
         return corpus
 
     def evaluate(self, field, gold, test=None, feats=None, label=None,
-                 batch_size=BATCH_SIZE, split=None, clone_ds=False,
-                 log_file=LOG_FILE, **ext_predict_kwargs):
+                 use_cdict_coef=False, batch_size=BATCH_SIZE, split=None,
+                 clone_ds=False, log_file=LOG_FILE, **ext_predict_kwargs):
         """Evaluate the tagger model.
 
         Args:
@@ -493,6 +504,12 @@ class BaseTagger(BaseParser):
         `field='FEATS:Animacy', label='Inan'`. Note that to evaluate key-value
         type fields like `FEATS` or `MISC`.
 
+        **use_cdict_coef** (`bool`|`float`): if `False` (default), we use our
+        prediction only. Elsewise, we replace our prediction to the value
+        returned by the `corpuscula.CorpusDict.predict_<field>()` method if
+        its `coef` >= `.99`. Also, you may specify your own threshold as the
+        value of the param. Relevant if **test** is not `None`.
+
         **batch_size** (`int`): number of sentences per batch. Default
         `batch_size=64`.
 
@@ -517,10 +534,10 @@ class BaseTagger(BaseParser):
         gold = self._get_corpus(gold, log_file=log_file)
         corpora = zip(self._get_corpus(test, log_file=log_file), gold) \
                       if test else \
-                  self.predict(gold, with_orig=True,
-                               batch_size=batch_size, split=split,
-                               clone_ds=clone_ds, log_file=log_file,
-                               **ext_predict_kwargs)
+                  self.predict(gold, use_cdict_coef=use_cdict_coef,
+                               with_orig=True, batch_size=batch_size,
+                               split=split, clone_ds=clone_ds,
+                               log_file=log_file, **ext_predict_kwargs)
         self._normalize_field_names(field)
         header = field.split(':')[:2]
         if len(header) == 2 and not header[1]:
@@ -659,7 +676,8 @@ class BaseTagger(BaseParser):
               word_emb_type='bert', word_emb_path=None,
               word_emb_model_device=None, word_emb_tune_params=None,
               word_transform_kwargs=None, word_next_emb_params=None,
-              seed=None, start_time=None, log_file=LOG_FILE, **model_kwargs):
+              seed=None, start_time=None, keep_embs=False, log_file=LOG_FILE,
+              **model_kwargs):
         """Creates and trains the tagger model.
 
         We assume all positional argumets but **save_as** are for internal use
@@ -773,6 +791,11 @@ class BaseTagger(BaseParser):
         **start_time** (`float`): result of `time.time()` to start with. If
         `None` (default), the arg will be init anew.
 
+        **keep_embs**: by default, after creating `Dataset` objects, we remove
+        word embedding models to free memory. With `keep_embs=False` this
+        operation is omitted, and you can use `.embs` attribute for share
+        embeddings models with other objects.
+
         **log_file**: a stream for info messages. Default is `sys.stdout`.
 
         **\*\*model_kwargs**: keyword arguments for the model creating. Will
@@ -901,6 +924,14 @@ class BaseTagger(BaseParser):
         else:
             ds_test = None
 
+        # remove emb models to free memory:
+        if not keep_embs:
+            ds_train._pull_xtrn()
+            if ds_test is not None:
+                ds_test._pull_xtrn()
+            self._embs = {}
+            gc.collect()
+
         model_config_fn, model_fn, _, _, cdict_fn = \
             self._get_filenames(save_as)
         self._save_cdict(cdict_fn)
